@@ -1,6 +1,6 @@
 from etools.async_http_client import AsyncHttpClient
 from etools.singleton_meta import SingletonMeta
-from http_common import extract_result
+from etools.http_common import extract_result
 
 
 class EAsyncHttpClient(AsyncHttpClient, metaclass=SingletonMeta):
